@@ -14,7 +14,7 @@ use Type::Library
 use Const::Fast ();
 use List::Util 1.33 ();
 use Type::Coercion;
-use Type::Tiny;
+use Type::Tiny 1.002001;
 use Type::Utils -all;
 use Types::Standard qw/ -types is_ArrayRef is_HashRef is_Ref /;
 use Types::TypeTiny ();
@@ -24,7 +24,7 @@ use Types::TypeTiny ();
 
 use namespace::autoclean 0.28;
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 
 declare ConstArrayRef,
@@ -151,7 +151,7 @@ Types::Const - Types that coerce references to read-only
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
